@@ -5,6 +5,8 @@ rand_color = function() {
     return(rgb(runif(1), runif(1), runif(1)))
 }
 
+op = par(no.readonly = TRUE)
+
 layout(matrix(1:9, 3, 3))
 for(i in 1:9) {
     factors = 1:8
@@ -21,4 +23,7 @@ for(i in 1:9) {
         circos.link(se[1], runif(2), se[2], runif(2), col = col)
     }
     circos.clear()
-}
\ No newline at end of file
+}
+
+par(op)
+layout(1)
